@@ -645,8 +645,13 @@ char *cs_get_exe(void)
 	/* Not using get_mm_exe_file() as it is not exported. */
 	rcu_read_lock();
 	exe_file = rcu_dereference(mm->exe_file);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6, 7, 0)
+	if (exe_file && !get_file_rcu(&exe_file))
+		exe_file = NULL;
+#else
 	if (exe_file && !get_file_rcu(exe_file))
 		exe_file = NULL;
+#endif
 	rcu_read_unlock();
 #elif LINUX_VERSION_CODE >= KERNEL_VERSION(4, 1, 0)
 	exe_file = get_mm_exe_file(mm);
